#### Image Detail

Image Name

An image name less than 256 characters is required.

Image Description

An image description less than 256 characters is required.

Format

#### Image Requirements

Kernel ID
Ramdisk ID
Architecture
Minimum Disk (GB)

min disk is required and must be an integer not less than 0

Minimum RAM (MB)

min ram is required and must be an integer not less than 0

#### Image Sharing

Visibility
{$ ::option.label $}
Protected
{$ ::option.label $}